embedNativeServerLibrary function

void embedNativeServerLibrary(
  1. List<int> bytes
)

Gives this process the native server library as bytes. Nothing to load where there is no FFI, so this only records that the call was made.

Implementation

void embedNativeServerLibrary(List<int> bytes) {}