AnalyticsProvider class abstract

Constructors

AnalyticsProvider()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

logEvent(String name, [Map<String, Object>? parameters]) → Future<void>
logScreenView(String screenName, {String? screenClass}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUserId(String? userId) → Future<void>
setUserProperty(String name, String value) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited