BuildConfig class

Platform-specific build configuration

Constructors

BuildConfig({required Platform platform, required String outputPath, bool release = false, Map<String, String> buildArgs = const {}})
const

Properties

buildArgs → Map<String, String>
final
hashCode → int
The hash code for this object.
no setterinherited
outputPath → String
final
platform → Platform
final
release → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateBuildCommand() → String
Generate the full build command
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited