DVAIAgentRequest class

Constructors

DVAIAgentRequest({required String goal, DVJsonObject context = const <String, DVJsonValue>{}, List<String> tools = const <String>[]})
const

Properties

context DVJsonObject
final
goal String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tools List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited