DVAIFallbackStep class

Constructors

DVAIFallbackStep({required String from, required String to, required DVAIFallbackReason reason})
const

Properties

from → String
The model given up on.
final
hashCode → int
The hash code for this object.
no setterinherited
reason → DVAIFallbackReason
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to → String
The model tried next, or degrade.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited