DVAIOpsError class

A declaration the AI operations layer refuses, carrying its diagnostic code (DV-AIOPS-005, DV-AIOPS-006).

Implemented types

Constructors

DVAIOpsError(String code, String message)
const

Properties

code → String
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited