DVAIToolEntry class

Constructors

DVAIToolEntry({required String name, required String description, required String importUri, required String filePath})
const

Properties

description → String
final
filePath → String
final
hashCode → int
The hash code for this object.
no setterinherited
importUri → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited