DVAIUnavailable class

The provider failed and nothing declared could answer (DV-AIOPS-004).

Inheritance

Constructors

DVAIUnavailable({required Object error, required List<DVAIFallbackStep> steps})
const

Properties

code → String
final
error → Object
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
steps → List<DVAIFallbackStep>
Every step down the fallback chain this run took.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited