DVAddIndex class final

An index over one or more columns.

Inheritance

Constructors

DVAddIndex(String table, List<String> columns, {String? name, bool unique = false})
const

Properties

columns → List<String>
final
description → String
A one-line description for a plan, e.g. add column orders.note.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → String
The table the change touches.
finalinherited
unique → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited