DVAlertWhen class

When a reading breaches.

The threshold is a number, or a Duration for a trace signal. The two are never compared with each other: 800 against a latency in microseconds is a rule that never fires, and one in seconds a rule that always does.

Constructors

DVAlertWhen.above(Object threshold)
const
DVAlertWhen.below(Object threshold)
const

Properties

above → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threshold → Object
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited