DVAppTrackingTransparency class abstract final

The App Tracking Transparency prompt, through the platform binding.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

applies ↔ bool Function()
Whether this platform asks tracking categories through the prompt.
getter/setter pair

Static Methods

request() → Future<DVTrackingAuthorization>
Shows the prompt, or answers what it answered before.

Constants

requestBinding → const String
The binding that shows the prompt and answers with ATTrackingManagerAuthorizationStatus, or -1 when it cannot be shown.