DVApplicationMenu class

Constructors

DVApplicationMenu(List<DVMenuItem> items)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
items → List<DVMenuItem>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited