DVAudioFormat enum
Audio container/codec pairs a recording can be asked for.
Values
- aac → const DVAudioFormat
-
AAC in an MPEG-4 container (
.m4a). - opus → const DVAudioFormat
-
Opus in Ogg (
.ogg). - wav → const DVAudioFormat
-
Uncompressed PCM (
.wav).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DVAudioFormat> - A constant List of the values in this enum, in order of their declaration.