DVAuthTokenResult class

The outcome of a redemption.

Constructors

DVAuthTokenResult.failed(DVAuthTokenFailure failure)
const
DVAuthTokenResult.success(String identifier)
const

Properties

failure → DVAuthTokenFailure?
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → String?
The identifier the token was issued for, when redemption succeeded.
final
isSuccess → bool
no setter
reveal → String
A message safe to show a user.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited