DVAuthTokenStore class abstract

Where issued tokens live between request and redemption.

Constructors

DVAuthTokenStore()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String lookup) → Future<void>
get(String lookup) → Future<DVAuthTokenRecord?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String lookup, DVAuthTokenRecord record) → Future<void>
toString() → String
A string representation of this object.
inherited
update(String lookup, DVAuthTokenRecord record) → Future<void>
Replaces a record, for attempt counting.

Operators

operator ==(Object other) → bool
The equality operator.
inherited