DVAuthUser class

Constructors

DVAuthUser({required String id, String? email, required String provider, Map<String, Object?> metadata = const {}, required DateTime createdAt})
const

Properties

createdAt → DateTime
final
email → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
metadata → Map<String, Object?>
final
provider → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited