DVBackfillProgress class final

Where a backfill has got to.

Constructors

DVBackfillProgress({required bool complete, required List<DVBackfillChunk> chunks})
const

Properties

chunks → List<DVBackfillChunk>
final
complete → bool
No rows remained past the last chunk when it last looked.
final
hashCode → int
The hash code for this object.
no setterinherited
mismatched → List<DVBackfillChunk>
no setter
rows → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unverified → List<DVBackfillChunk>
no setter
verified → bool
Every chunk backfilled and every chunk verified clean.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited