DVCaptureInterrupted class final

Recording stopped before the application stopped it. partial is what was recorded up to then, still private, when there is any.

Implemented types

Constructors

DVCaptureInterrupted(DVCaptureInterruption reason, DVFile? partial)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
partial → DVFile?
final
reason → DVCaptureInterruption
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited