DVChangeColumnType class final

An existing column given a different type.

Inheritance

Constructors

DVChangeColumnType(String table, String column, {required String from, required String to})
const

Properties

column → String
final
description → String
A one-line description for a plan, e.g. add column orders.note.
no setteroverride
from → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → String
The table the change touches.
finalinherited
to → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited