DVComfortOptions class final

The comfort options an immersive space offers.

Constructors

DVComfortOptions({Set<DVLocomotion> locomotion = const <DVLocomotion>{}, bool vignette = false, bool seated = false})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
locomotion → Set<DVLocomotion>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seated → bool
final
vignette → bool
Narrowing the view while moving.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited