DVComfortResolution class final

What the policy made of what was declared.

Constructors

DVComfortResolution(DVComfortOptions effective, List<String> codes)
const

Properties

codes → List<String>
DV-XR-005 when smooth locomotion was offered with nothing to soften it.
final
effective → DVComfortOptions
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited