DVConsentChange class final

Which categories a change granted and which it withdrew.

Constructors

DVConsentChange({required Set<DVConsentCategory> granted, required Set<DVConsentCategory> withdrawn})
const

Properties

granted → Set<DVConsentCategory>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withdrawn → Set<DVConsentCategory>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited