DVContentChangedAfterApproval class

The version changed after it was approved, so publishing it would ship text nobody approved (DV-CONTENT-002).

Implemented types

Constructors

DVContentChangedAfterApproval(String versionId, {required int? approvedRevision, required int revision})

Properties

approvedRevision → int?
The revision the approval was given on, or null when there is none.
final
code → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
revision → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited