ingestPerInstallPerHour property
With sink: dartvel, the reports the backend stores per install per
hour; past it they are counted.
Implementation
final int ingestPerInstallPerHour;
With sink: dartvel, the reports the backend stores per install per
hour; past it they are counted.
final int ingestPerInstallPerHour;