DVCrashKind enum

How a report came about.

Inheritance
Available extensions

Values

fatal → const DVCrashKind

The process was going down.

nonFatal → const DVCrashKind

A caught error the application asked to have recorded. The only kind that is sampled.

hang → const DVCrashKind

The platform thread stopped answering for longer than the threshold.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DVCrashKind>
A constant List of the values in this enum, in order of their declaration.