DVDeviceHealth class

Constructors

DVDeviceHealth({required bool healthy, required DateTime checkedAt, Map<String, String> diagnostics = const <String, String>{}})
const
DVDeviceHealth.fromMap(Map<Object?, Object?> map)
factory

Properties

checkedAt → DateTime
final
diagnostics → Map<String, String>
final
hashCode → int
The hash code for this object.
no setterinherited
healthy → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited