onRestartLoop property
Called when a restart loop is detected instead of restarting again (DV-KIOSK-008). The app shows its diagnostics screen from here.
Implementation
static void Function(String finding)? onRestartLoop;
Called when a restart loop is detected instead of restarting again (DV-KIOSK-008). The app shows its diagnostics screen from here.
static void Function(String finding)? onRestartLoop;