DVDigitalBillable class final

Inheritance

Constructors

DVDigitalBillable({String? appStore, String? play})
const

Properties

appStore → String?
The App Store Connect product identifier.
final
hashCode → int
The hash code for this object.
no setterinherited
play → String?
The Play Console product identifier.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

identifierOn(DVStore store) → String?
The identifier store knows this product by, or null when none was declared.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited