DVDiscount class sealed

What a promotion takes off.

Constructors

DVDiscount.basisPoints(int basisPoints)
Hundredths of a percent, for 12.5% and the like.
const
factory
DVDiscount.fixed(DVMoney amount)
A fixed amount, capped at what the eligible lines cost.
const
factory
DVDiscount.percent(int percent)
A whole percentage of the eligible lines.
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate() → void
Throws when the discount cannot be applied as declared.

Operators

operator ==(Object other) → bool
The equality operator.
inherited