DVDiscount.fixed constructor
const
DVDiscount.fixed(
- DVMoney amount
A fixed amount, capped at what the eligible lines cost.
Implementation
const factory DVDiscount.fixed(DVMoney amount) = DVFixedDiscount;
A fixed amount, capped at what the eligible lines cost.
const factory DVDiscount.fixed(DVMoney amount) = DVFixedDiscount;