DVDisplayControls class
Constructors
- DVDisplayControls()
-
const
Properties
- currentState → DVDisplayState
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFullscreen → bool
-
no setter
- isKiosk → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disableKiosk(
) → Future< void> -
enableKiosk(
[DVKioskOptions options = const DVKioskOptions()]) → Future< void> -
enterFullscreen(
[DVFullscreenOptions options = const DVFullscreenOptions()]) → Future< void> -
exitFullscreen(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited