DVDisplayResolution class final

What a hint resolved to, and whether it was what was asked for.

Constructors

DVDisplayResolution({required DVDisplay? display, required bool exact, required DVWindowDegradation degradation})
const

Properties

degradation → DVWindowDegradation
final
display → DVDisplay?
The display the hint named, or null when nothing matched it.
final
exact → bool
Whether the hint was honoured.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited