DVEntitlementSnapshots class
The entitlement snapshots a device holds, checked against its clock.
Constructors
-
DVEntitlementSnapshots(List<
DVEntitlementSnapshot> snapshots, {DateTime clock()?, DVLogger? logger})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
snapshots
→ List<
DVEntitlementSnapshot> -
final
Methods
-
entitled(
Entitlement entitlement) → bool -
Whether a snapshot for
entitlementis still inside itsnotAfter. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited