DVErasureDeadlines class

What a deadline check found and did: open erasures requested and not yet completed, overdue of them past the deadline, and the results of the ones it ran.

Constructors

DVErasureDeadlines({required int open, required int overdue, required List<DVErasureResult> results})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
open → int
final
overdue → int
final
results → List<DVErasureResult>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited