DVFakeMediaTimers class final

Timers that fire when the test says time has passed.

Implemented types

Constructors

DVFakeMediaTimers()

Properties

hashCode → int
The hash code for this object.
no setterinherited
now → Duration
How much fake time has passed.
no setter
pending → int
Timers scheduled and neither fired nor cancelled.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

elapse(Duration by) → void
Advances time by by, firing every timer that falls due, in order.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(Duration after, void onFire()) → DVMediaTimer
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited