DVFlagExposedEvent class

A feature flag's exposure, as the event Feature Flags records it as.

Inheritance

Constructors

DVFlagExposedEvent(DVFlagExposure exposure, DVConsentCategory category)
const

Properties

category → DVConsentCategory
final
exposure → DVFlagExposure
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setteroverride
properties → Map<String, Object?>
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited