DVFormControls class

Constructors

DVFormControls(Object? model, {void onSubmit()?, void onReset()?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
model Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
submit() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited