DVHangWatchdog class
Notices when the platform thread stops answering.
The platform thread calls beat; something on another thread calls check on a timer. One freeze is one hang however often check looks.
Constructors
- DVHangWatchdog({required Duration threshold, required DateTime clock(), required void onHang(Duration blockedFor)})
Properties
Methods
-
beat(
) → void -
check(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited