DVHttpFake class
Faked outbound HTTP, and what it was asked.
Constructors
-
DVHttpFake(Map<
String, DVHttpStub> stubs)
Properties
-
calls
→ List<
DVHttpCall> -
Every request a stub answered, in order.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stubs
→ Map<
String, DVHttpStub> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited