DVHttpHost class

A declared host's requests.

Properties

config → DVHttpHostConfig
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String path, {Map<String, String> headers = const <String, String>{}, int? attempts}) → Future<Response>
get(String path, {Map<String, String> headers = const <String, String>{}, int? attempts}) → Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(String path, {Object? json, Object? body, Map<String, String> headers = const <String, String>{}, String? idempotencyKey, int? attempts}) → Future<Response>
post(String path, {Object? json, Object? body, Map<String, String> headers = const <String, String>{}, String? idempotencyKey, int? attempts}) → Future<Response>
put(String path, {Object? json, Object? body, Map<String, String> headers = const <String, String>{}, String? idempotencyKey, int? attempts}) → Future<Response>
send(String method, String path, {Object? json, Object? body, Map<String, String> headers = const <String, String>{}, String? idempotencyKey, int? attempts}) → Future<Response>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited