DVHttpRequest class

Constructors

DVHttpRequest({required Uri url, String method = 'POST', Map<String, String> headers = const <String, String>{}, List<int> body = const <int>[], DVHttpProtocolChain protocols = DVHttpProtocolChain.standard, DVEarlyHintsCallback? onEarlyHints})
const

Properties

body List<int>
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
method String
final
onEarlyHints DVEarlyHintsCallback?
Called for each 103 Early Hints response that arrives before the final one. Never called after the response returns.
final
protocols DVHttpProtocolChain
Protocols to attempt, best first.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url Uri
final

Methods

forProtocol(DVHttpProtocol protocol) DVHttpRequest
A copy of this request pinned to protocol.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited