DVI18n class

Constructors

DVI18n()
const

Properties

currentLocale → LocaleTag
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textDirection → TextDirection
no setter

Methods

formatCurrency(num value, {String code = 'USD', LocaleTag? locale}) → String
formatDate(DateTime value, {LocaleTag? locale}) → String
formatNumber(num value, {LocaleTag? locale}) → String
load(DVTranslationCatalog catalog) → void
loadAll(Iterable<DVTranslationCatalog> catalogs) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
plural(DVTranslationKey key, num count, {Map<String, String> args = const <String, String>{}, LocaleTag? locale, bool strict = false}) → String
reset() → void
t(DVTranslationKey key, {Map<String, String> args = const <String, String>{}, LocaleTag? locale, bool strict = false}) → String
toString() → String
A string representation of this object.
inherited
translate(DVTranslationKey key, {Map<String, String> args = const <String, String>{}, LocaleTag? locale, bool strict = false}) → String
useLocale(LocaleTag locale) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited