DVImportResult<TModel> class

Constructors

DVImportResult({required List<TModel> items, List<DVImportRowError> errors = const <DVImportRowError>[]})
const

Properties

errors → List<DVImportRowError>
final
hasErrors → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
items → List<TModel>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited