DVIncidentStore class abstract

Where incidents are kept.

Constructors

DVIncidentStore()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

all() → Future<List<DVIncident>>
find(String id) → Future<DVIncident?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(DVIncident incident) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited