DVInfraBackup class final

database.backup.

Constructors

DVInfraBackup({required String schedule, required Duration retain, required Duration verifiedRestoreWithin})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
retain → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule → String
A five-field cron line.
final
verifiedRestoreWithin → Duration
How old the last verified restore may be before DV-INFRA-004.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited