requiresRelease property

bool requiresRelease
final

A unit that runs the released binary. It cannot run before a release has put one on the host, so it is enabled but not started until then.

Implementation

final bool requiresRelease;