DVJob class

Annotation for a durable background job.

Constructors

DVJob({String? queue, int priority = 0, int maxAttempts = 3, int backoffSeconds = 30})
const
DVJob.handler()
Marks the function that runs a job: @DVJob.handler().
const

Properties

backoffSeconds → int
final
hashCode → int
The hash code for this object.
no setterinherited
isHandler → bool
Whether this annotation marks a handler function rather than a payload class. Set only by DVJob.handler.
final
maxAttempts → int
final
priority → int
final
queue → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited