DVKioskExitRequest class

A request to leave kiosk mode.

Constructors

DVKioskExitRequest.adminAuth(String token)
An authenticated administrator.
const
DVKioskExitRequest.pin(String pin)
A PIN entry.
const
DVKioskExitRequest.remote(String token)
A remote management instruction.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
method → DVKioskExitMethod
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited