DVKioskOptions class

Constructors

DVKioskOptions({bool fullscreen = true, bool disableBackGesture = true, bool keepScreenAwake = true, List<String> allowedExitKeys = const <String>[]})
const

Properties

allowedExitKeys List<String>
final
disableBackGesture bool
final
fullscreen bool
final
hashCode int
The hash code for this object.
no setterinherited
keepScreenAwake bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited