DVKioskReset class

What a reset cleared, and where it left the kiosk.

Constructors

DVKioskReset({required Set<DVKioskClearable> cleared, required String home, required DVKioskResetReason reason})
const

Properties

cleared → Set<DVKioskClearable>
final
hashCode → int
The hash code for this object.
no setterinherited
home → String
final
reason → DVKioskResetReason
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited