DVLdapClient class

An LDAP connection, which cannot be opened here.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(String dn, String password) → Future<bool>
close() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

connect({required String host, int port = 389, bool useTls = false, Duration timeout = const Duration(seconds: 10), bool allowBadCertificate = false}) → Future<DVLdapClient>