DVMacosDragDrop class

The macOS dragging destination, unavailable here.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

accepting → bool
no setter
lastError ↔ String?
getter/setter pair

Static Methods

eventFrom(Object? pasteboard, {double x = 0, double y = 0}) → DVDropEvent
unregister() → void

Constants

implemented → const Set<String>