DVMediaBackendCapabilities class final

What a backend on this target can do. Reported, never assumed.

Constructors

DVMediaBackendCapabilities({bool adaptiveStreaming = true, bool backgroundAudio = false, bool pictureInPicture = false, bool video = true})
const

Properties

adaptiveStreaming → bool
Plays HLS/DASH manifests itself.
final
backgroundAudio → bool
Can keep playing while the application is in the background.
final
hashCode → int
The hash code for this object.
no setterinherited
pictureInPicture → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
video → bool
Can render frames rather than audio alone.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited