DVMemoryCrashSymbols class

Implemented types

Constructors

DVMemoryCrashSymbols({Set<String> releases = const <String>{}})

Properties

hashCode → int
The hash code for this object.
no setterinherited
releases → Set<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

has(String release) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited