DVMemoryHeapBacking class final

Segments allocated as typed data on the Dart heap.

The web backing, and a portable one for tests. touchPages is a no-op: typed data is zeroed as it is allocated.

Implemented types

Constructors

DVMemoryHeapBacking()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reserve(int bytes, {required bool touchPages}) → DVMemorySegmentStore?
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited