address property

  1. @override
int get address
override

The native address of the first byte, or 0 when the segment lives on the Dart heap (web, or DVMemoryHeapBacking) and has none.

Implementation

@override
int get address => 0;