put method
Writes grant, replacing any grant for the same purchase.
Implementation
@override
Future<void> put(DVPurchaseGrant grant) async {
_grants[_key(grant.store, grant.originalTransactionId)] = grant;
}
Writes grant, replacing any grant for the same purchase.
@override
Future<void> put(DVPurchaseGrant grant) async {
_grants[_key(grant.store, grant.originalTransactionId)] = grant;
}