DVMemoryTraceExporter class

Keeps them in a list. For tests, and for dartvel inspect.

Implemented types

Constructors

DVMemoryTraceExporter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spans → List<DVSpan>
final

Methods

clear() → void
export(DVSpan span) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited