DVMeterRecord class

One stored recording.

Constructors

DVMeterRecord({required String tenant, required String meter, required String idempotencyKey, required num amount, required DateTime at, required DVMeterPeriod period})
const

Properties

amount → num
final
at → DateTime
When the usage happened.
final
hashCode → int
The hash code for this object.
no setterinherited
idempotencyKey → String
final
meter → String
final
period → DVMeterPeriod
The period it was counted in, which for a late record can be a different one from the period at falls in.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenant → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited