period property
The period it was counted in, which for a late record can be a different one from the period at falls in.
Implementation
final DVMeterPeriod period;
The period it was counted in, which for a late record can be a different one from the period at falls in.
final DVMeterPeriod period;