DVModel3DProblemKind enum
Why an upload was refused.
Values
- format → const DVModel3DProblemKind
-
Not a glTF 2.0 model this runtime can read.
- size → const DVModel3DProblemKind
-
Over the field's size ceiling.
- triangles → const DVModel3DProblemKind
-
Draws more triangles than the field's budget.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DVModel3DProblemKind> - A constant List of the values in this enum, in order of their declaration.