DVModelChange<T> class

One model change, as delivered to watchers.

Constructors

DVModelChange({required DVModelChangeKind kind, required T model, String? tenant, DateTime? at})

Properties

at DateTime
final
hashCode int
The hash code for this object.
no setterinherited
kind DVModelChangeKind
final
model → T
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenant String
The tenant the change belongs to, captured when it was published.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited