DVModuleEnvironment enum

The three places a module can be called from.

Inheritance
Available extensions

Values

native → const DVModuleEnvironment

A client built for Android, iOS, macOS, Windows, Linux or a TV.

web → const DVModuleEnvironment

A client running in a browser.

backend → const DVModuleEnvironment

The application's server: a Dart VM with no Flutter engine.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

current → DVModuleEnvironment
The environment this code was compiled for.
no setter

Constants

values → const List<DVModuleEnvironment>
A constant List of the values in this enum, in order of their declaration.