DVMySqlConnection class abstract

One MySQL connection. Abstracted like the Postgres and Redis transports.

Constructors

DVMySqlConnection()

Properties

hashCode → int
The hash code for this object.
no setterinherited
input → Stream<List<int>>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
upgradeToTls({required String host, required DVSslMode sslMode}) → Future<void>
Wrap this connection in TLS, in place.
write(List<int> bytes) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited