DVNfc class
Constructors
- DVNfc()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isAvailable(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readTag(
) → Future< String> -
toString(
) → String -
A string representation of this object.
inherited
-
writeTag(
String value, {String language = 'en'}) → Future< bool> -
Writes
valueto the tag currently on the reader.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited