DVOAuth2Tokens class

Constructors

DVOAuth2Tokens({required String accessToken, String? refreshToken, String? idToken, String tokenType = 'Bearer', Duration? expiresIn, List<String> scopes = const <String>[]})
const

Properties

accessToken → String
final
expiresIn → Duration?
final
hashCode → int
The hash code for this object.
no setterinherited
idToken → String?
final
refreshToken → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → List<String>
final
tokenType → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited