DVOAuthTokenResponse class

A token endpoint response.

Constructors

DVOAuthTokenResponse({required String accessToken, required Duration expiresIn, required List<String> scopes, String? refreshToken})
const

Properties

accessToken → String
final
expiresIn → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
refreshToken → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → List<String>
final
tokenType → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited