DVObjective class

What a service level promises.

Constructors

DVObjective.successRate(double target, {required Duration over})
target of requests succeed, measured over the trailing over.
const

Properties

budget → double
The share of requests allowed to fail.
no setter
budgetTime → Duration
How long total failure the window allows: 43.2 minutes for 99.9% over thirty days.
no setter
hashCode → int
The hash code for this object.
no setterinherited
over → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited