DVOrderLine class

One line of an order.

Constructors

DVOrderLine({required String reference, required String productId, required DVMoney unitPrice, required DVTaxCategory category, int quantity = 1})

Properties

amount → DVMoney
The line's price before discounts: unitPrice times quantity.
no setter
category → DVTaxCategory
How the line is taxed. Declared on the line because the order is what is taxed, and the same product can be sold as two categories.
final
hashCode → int
The hash code for this object.
no setterinherited
productId → String
final
quantity → int
final
reference → String
The application's name for the line, unique in the order.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unitPrice → DVMoney
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited