DVPayoutRecord class

A payout, reserved or completed.

Constructors

DVPayoutRecord({required String id, required String accountId, required DVMoney amount, required DateTime at, String? transferReference})
const

Properties

accountId → String
final
amount → DVMoney
final
at → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transferReference → String?
The provider's transfer, once made.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited