DVPayoutSaleRecord class

A sale as the payout ledger knows it: what it collected and how that was divided.

Constructors

DVPayoutSaleRecord({required String saleId, required DVMoney collected, required Map<String, int> shares, int reversed = 0})

Properties

collected → DVMoney
final
hashCode → int
The hash code for this object.
no setterinherited
reversed → int
How much of collected refunds and lost disputes have reversed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleId → String
final
shares → Map<String, int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited