DVPhysicalBillable class final
See DVBillable.physical.
- Inheritance
-
- Object
- DVBillable
- DVPhysicalBillable
Constructors
- DVPhysicalBillable({int? nativePrice, String? nativeCurrency})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nativeCurrency → String?
-
final
- nativePrice → int?
-
The gateway price in nativeCurrency's minor units. Never a store price.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited