DVPlayStorePolicy class

Google Play's conservative default policy.

Inheritance

Constructors

DVPlayStorePolicy()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
route({required DVPurchaseProduct product, required DVPurchaseChannel channel, String? jurisdiction}) → DVPurchaseRoute
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited