DVPrinting class
Constructors
- DVPrinting()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
print(
{required List< Uint8List> pages, String? title}) → Future<DVPrintResult> -
Shows the platform's print dialog for
pages. Resolves when the dialog closes; DVPrintResult.pages is 0 if it was cancelled. -
toFile(
String path, {required List< Uint8List> pages, String? title}) → Future<DVPrintResult> -
Writes
pagesto a PDF atpath, one picture per page. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited