DVPrivacyFinding class

A problem with the declarations, found before anything runs.

Constructors

DVPrivacyFinding({required String code, required String model, required String message, required DVLogLevel level})
const

Properties

code → String
final
hashCode → int
The hash code for this object.
no setterinherited
level → DVLogLevel
final
message → String
final
model → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited