DVPromotionPolicy class abstract

Whether a customer may redeem a promotion: the @DVPolicy the specification writes as redeem(User user, Coupon coupon).

Constructors

DVPromotionPolicy()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
redeem(Object customer, DVPromotion promotion) → FutureOr<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited