DVProtocolVersionPlan class

What one served protocol version gets.

Constructors

DVProtocolVersionPlan({required int protocol, required DVProtocolResult result, required List<DVProtocolChange> changes})
const

Properties

changes → List<DVProtocolChange>
final
hashCode → int
The hash code for this object.
no setterinherited
protocol → int
final
result → DVProtocolResult
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited