DVPublicIncidentUpdate class

One public update on an incident.

Constructors

DVPublicIncidentUpdate({required DateTime at, required String message, DVIncidentStatus? status})
const

Properties

at → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → DVIncidentStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, Object?> json) → DVPublicIncidentUpdate