discard abstract method

Future<bool> discard(
  1. String id
)

Drops one dead-lettered job. Flushing a queue to be rid of a single poison message would take every other job with it.

Implementation

Future<bool> discard(String id);