DVRefundReservation class

What reserving a refund did.

Constructors

DVRefundReservation({DVRefund? refund, bool existed = false, int? remaining})
const

Properties

existed → bool
A refund with this id was already there.
final
hashCode → int
The hash code for this object.
no setterinherited
refund → DVRefund?
The reservation, or null when refused.
final
remaining → int?
What was left, when refused.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited