DVRequestLifecycle enum

Backend request lifecycle states, observed through context.lifecycle.request.

Inheritance
Available extensions

Values

received → const DVRequestLifecycle
contextCreated → const DVRequestLifecycle
decoding → const DVRequestLifecycle
tenantResolving → const DVRequestLifecycle
tenantResolved → const DVRequestLifecycle
authenticating → const DVRequestLifecycle
authenticated → const DVRequestLifecycle
securityChecking → const DVRequestLifecycle
rateLimitChecking → const DVRequestLifecycle
validating → const DVRequestLifecycle
authorized → const DVRequestLifecycle
transactionStarting → const DVRequestLifecycle
executing → const DVRequestLifecycle
preparingResponse → const DVRequestLifecycle
committing → const DVRequestLifecycle
encoding → const DVRequestLifecycle
completed → const DVRequestLifecycle
cancelled → const DVRequestLifecycle
rollingBack → const DVRequestLifecycle
failed → const DVRequestLifecycle

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DVRequestLifecycle>
A constant List of the values in this enum, in order of their declaration.