DVRetentionPlan class

Properties

anonymizations → Map<String, int>
final
deletions → Map<String, int>
final
hashCode → int
The hash code for this object.
no setterinherited
held → Map<String, int>
Expired under the model's retention, but held by a longer one.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited