onRelease method
Called when a grab on this node is released, in a spatial session.
Implementation
Self onRelease(VoidCallback handler) =>
_copy(_props.copyWith(onRelease: handler)) as Self;
Called when a grab on this node is released, in a spatial session.
Self onRelease(VoidCallback handler) =>
_copy(_props.copyWith(onRelease: handler)) as Self;