onTap method

Self onTap(
  1. VoidCallback handler
)

Called when this node, or a child with no handler of its own, is the nearest thing under a tap.

Implementation

Self onTap(VoidCallback handler) =>
    _copy(_props.copyWith(onTap: handler)) as Self;