DVSceneRenderer class abstract interface

A 3D renderer.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
For reports, e.g. flutter_gpu.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Called once, after every resource has been released.
initialize() → FutureOr<DV3DDegradation>
Starts the renderer. DV3DDegradation.none when it can draw; a renderer that throws is treated as DV3DDegradation.gpuInitFailed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release(DVSceneResource resource) → void
Frees resource. Called exactly once per upload.
render(DVSceneFrame frame) → void
toString() → String
A string representation of this object.
inherited
upload(String assetKey, DVSceneAsset asset, DVSceneAssetState loaded) → DVSceneResource
Makes a resource from a loaded asset.

Operators

operator ==(Object other) → bool
The equality operator.
inherited