DVSchemaPlanner class final

Classifies changes and plans the safe version of a blocking one.

Constructors

DVSchemaPlanner()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
plan(Iterable<DVSchemaChange> changes, DVSchemaClassifier? classifier, {Map<String, int> rows = const <String, int>{}}) → Future<DVSchemaPlan>
Plans changes with the classification classifier gives.
planFor(DVDatabaseAdapter adapter, Iterable<DVSchemaChange> changes) → Future<DVSchemaPlan>
Plans changes with the classification adapter gives for the server it is connected to.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

shadowColumn(String column) → String
The name the new shape is written under until the contract renames it.