DVSchemaReleaseGate class final

The schema production gate, read before deploy.

Implemented types

Constructors

DVSchemaReleaseGate({required DVSchemaPlan plan, bool production = true, String name = 'schema'})

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Unique within a composition; overrides address a gate by it.
final
phases → Set<DVReleasePhase>
The phases this gate is read in.
no setteroverride
plan → DVSchemaPlan
final
production → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluate(DVReleaseGateContext context) → DVGateOutcome
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited