DVSearchProvider<TModel, TFacets> class abstract

Constructors

DVSearchProvider()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(String query, {TFacets? facets, int page = 1, int perPage = 20}) → Future<DVSearchResultPage<TModel>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited