DVSemanticBackfill class
Constructors
- DVSemanticBackfill({required String generation, required int processed, required int total, required bool completed})
-
const
Properties
- completed → bool
-
Whether generation now answers queries.
final
- generation → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- processed → int
-
How many of the given records are now embedded in generation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited