DVSessionFailure enum
Why a token did not authenticate.
Values
- unknown → const DVSessionFailure
-
No session has this token — never issued, or rotated away.
- revoked → const DVSessionFailure
-
The session was revoked, here or on another device.
- expired → const DVSessionFailure
-
Idle for longer than the idle timeout, or older than the absolute one.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DVSessionFailure> - A constant List of the values in this enum, in order of their declaration.