DVSessionRequestFailed class

A request to the generated auth endpoints that the server did not answer as asked. Carries the status and the path, never the body.

Implemented types

Constructors

DVSessionRequestFailed(int statusCode, String path)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited