DVSignalReadingStatus enum
Values
- value → const DVSignalReadingStatus
-
A value was read.
- noData → const DVSignalReadingStatus
-
The signal exists and has nothing to say: no spans in the window, no sessions, no series for these labels yet.
- missing → const DVSignalReadingStatus
-
Nothing by that name exists to read.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DVSignalReadingStatus> - A constant List of the values in this enum, in order of their declaration.