DVSqliteSchemaRules class final
What SQLite -- and Turso and other libSQL builds -- does with each change.
- Implemented types
Constructors
- DVSqliteSchemaRules(DVDatabaseServerVersion version)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → DVDatabaseServerVersion
-
final
Methods
-
classify(
DVSchemaChange change) → DVSchemaChangeClass? -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited