DVStartupPhase class

One phase of startup: what it was, when it ended, and how long it took.

Constructors

DVStartupPhase({required String name, required Duration at, required Duration elapsed})
const

Properties

at → Duration
How far into startup this phase ended.
final
elapsed → Duration
How long it took, measured from the phase before it.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited