DVStatefulShellRoute class
Tabs: each branch keeps its own navigation stack.
StatefulShellRoute.indexedStack, typed.
- Inheritance
-
- Object
- DVRouteNode
- DVStatefulShellRoute
Constructors
-
DVStatefulShellRoute({required DVStatefulShellBuilder builder, required List<
DVShellBranch> branches, DVRouteRedirect? redirect}) -
const
Properties
-
branches
→ List<
DVShellBranch> -
final
- builder → DVStatefulShellBuilder
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- redirect → DVRouteRedirect?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited