DVStripeDisputeEvents class

Stripe's dispute events, read.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(Map<String, Object?> event) → DVDisputeEvent?
The dispute event in a verified Stripe event, or null when it is some other kind of event.

Constants

types → const Set<String>