DVStudioComponentProp class

One prop of a component: its name, its kind, and the value a use that does not set it gets.

Annotations

Constructors

DVStudioComponentProp(String name, DVStudioPropKind kind, Object? value)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind → DVStudioPropKind
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Object?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Object? json) → DVStudioComponentProp?