DVStudioSegment<T> class

One option in a DVStudioSegmented.

Constructors

DVStudioSegment({required T value, String? label, IconData? icon, String? tooltip})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
final
label → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tooltip → String?
final
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited