DVThreePaneFold enum
Across one fold, which of DVBox.threePane's panes share a side.
Values
- firstAlone → const DVThreePaneFold
-
The first pane has a side; the second and third share the other.
- lastAlone → const DVThreePaneFold
-
The first and second share a side; the third has the other.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DVThreePaneFold> - A constant List of the values in this enum, in order of their declaration.