DVTracer class

Starts spans.

Constructors

DVTracer({DVTraceExporter? exporter, DVTraceSampler? sampler})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startSpan(String name, {DVSpan? parent, DVTraceContext? context}) → DVSpan
Begins a span.
toString() → String
A string representation of this object.
inherited
trace<T>(String name, Future<T> body(DVSpan span), {DVSpan? parent, DVTraceContext? context}) → Future<T>
Runs body inside a span, ending it either way and recording a throw.

Operators

operator ==(Object other) → bool
The equality operator.
inherited