DVTrackResult class final

What DVAnalytics.track did with an event.

Constructors

DVTrackResult.refused({String? code, required String reason})
An event that was not recorded for a reason outside the pipeline, such as a pipeline that could not start.
const

Properties

accepted → bool
final
code → String?
The diagnostic that explains a drop, when there is one.
final
hashCode → int
The hash code for this object.
no setterinherited
reason → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited