DVTrackingAuthorization enum
What the system prompt answered.
Values
- notDetermined → const DVTrackingAuthorization
-
Nobody has been asked yet.
- restricted → const DVTrackingAuthorization
-
Tracking is not allowed on this device, by a profile or parental control; the person could not have been asked.
- denied → const DVTrackingAuthorization
-
The person said no.
-
The person said yes.
-
There was no prompt to show.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DVTrackingAuthorization> - A constant List of the values in this enum, in order of their declaration.