DVTransactionLifecycle enum

Transaction lifecycle states, observed through context.lifecycle.transaction.

Inheritance
Available extensions

Values

created → const DVTransactionLifecycle
active → const DVTransactionLifecycle
preparing → const DVTransactionLifecycle
committing → const DVTransactionLifecycle
committed → const DVTransactionLifecycle
rollingBack → const DVTransactionLifecycle
rolledBack → const DVTransactionLifecycle
compensating → const DVTransactionLifecycle
compensated → const DVTransactionLifecycle
cancelled → const DVTransactionLifecycle
failed → const DVTransactionLifecycle

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DVTransactionLifecycle>
A constant List of the values in this enum, in order of their declaration.