DVTransfer class

A transfer the provider made.

Constructors

DVTransfer({required String reference, required String accountId, required DVMoney amount})
const

Properties

accountId → String
final
amount → DVMoney
final
hashCode → int
The hash code for this object.
no setterinherited
reference → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited