activated property
Stream<void>
get
activated
Every click on the icon itself, where the desktop sends one and
onActivate was given.
Implementation
Stream<void> get activated => _activated.stream;
Every click on the icon itself, where the desktop sends one and
onActivate was given.
Stream<void> get activated => _activated.stream;