DVUseMiddleware class

Typed annotation for page, layout, model, storage, and backend middleware.

Constructors

DVUseMiddleware(List<DVMiddlewareKey> middleware)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
middleware List<DVMiddlewareKey>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited