DVWebhookAddressRefusedException class

DV-WEBHOOK-002: an endpoint address a delivery may not go to.

Implemented types

Constructors

DVWebhookAddressRefusedException(Uri url, String reason)
const

Properties

code → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
reason → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited