DVWindowPerformanceFinding class

Constructors

DVWindowPerformanceFinding({required DVWindowPerformanceIssue kind, required String subject, required int count, required String message})
const

Properties

count → int
final
hashCode → int
The hash code for this object.
no setterinherited
kind → DVWindowPerformanceIssue
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String
The route, key or workspace the finding is about.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited