DVWindowTearOutSample class

Constructors

DVWindowTearOutSample({required String route, required Duration elapsed})
const

Properties

elapsed → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
route → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited