DvI18n class

Constructors

DvI18n()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

normalize(String? raw, List<String> allowed, String fallback) → String
parseLocale(String tag) → Locale
A BCP 47 language tag as a Locale.
updateLang(BuildContext context, String param, String newLang) → void