LocalAnalyticsProvider class

In-memory analytics provider for local development and tests.

Implemented types

Constructors

LocalAnalyticsProvider()

Properties

events → List<AnalyticsEvent>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ String?
getter/setter pair
userProperties → Map<String, String>
final

Methods

logEvent(String name, [Map<String, Object>? parameters]) → Future<void>
override
logScreenView(String screenName, {String? screenClass}) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUserId(String? userId) → Future<void>
override
setUserProperty(String name, String value) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited