LocaleTag class

Constructors

LocaleTag(String value)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isRightToLeft → bool
no setter
locale → Locale
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

enUS → const LocaleTag
frFR → const LocaleTag