MiddlewareChain class

Middleware chain executor

Constructors

MiddlewareChain()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(Object? request) → Future<MiddlewareContext>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
use(Middleware middleware) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited