MiddlewareManager class

Global middleware manager

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(Object? request, String path) → Future<MiddlewareContext>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
useForRoute(String path, Middleware middleware) → void
useGlobal(Middleware middleware) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → MiddlewareManager
no setter