OtaUpdater class

OTA Update manager

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAndUpdate({bool silent = false, void onUpdateAvailable(UpdateCheckResult)?, void onProgress(UpdateProgress)?}) → Future<void>
checkForUpdate() → Future<UpdateCheckResult>
configure({required String updateServerUrl, required String currentVersion, String? platform}) → void
downloadUpdate(String url) → Stream<UpdateProgress>
installUpdate(String updatePath) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → OtaUpdater
no setter