Platform enum

Supported platforms for Dartvel framework

Inheritance
Available extensions

Values

android → const Platform
ios → const Platform
windows → const Platform
macos → const Platform
linux → const Platform
androidTV → const Platform
appleTV → const Platform
tizenOS → const Platform
webOS → const Platform
embeddedLinux → const Platform
fireOS → const Platform
web → const Platform

Properties

buildCommand → String
Get the platform build command
no setter
displayName → String
Get the platform display name
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsNativeCode → bool
Check if the platform supports native code
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Platform>
A constant List of the values in this enum, in order of their declaration.