PlatformConfig class

Platform configuration for Dartvel

Constructors

PlatformConfig({Set<Platform> enabledPlatforms = const {Platform.android, Platform.ios, Platform.web, Platform.windows, Platform.macos, Platform.linux}, Map<Platform, Map<String, Object?>> platformSettings = const {}})
const

Properties

enabledPlatforms → Set<Platform>
final
hashCode → int
The hash code for this object.
no setterinherited
platformSettings → Map<Platform, Map<String, Object?>>
final
platformStatus → Map<Platform, bool>
Get all supported platforms with their status
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSettingsFor(Platform platform) → Map<String, Object?>?
Get settings for a platform
isPlatformEnabled(Platform platform) → bool
Check if a platform is enabled
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

detectCurrent() → Platform
Detect the current running platform