PushNotifications class

Push notifications manager

Constructors

PushNotifications()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

onMessage → Stream<PushNotification>
no setter
onMessageOpenedApp → Stream<PushNotification>
no setter

Static Methods

getToken() → Future<String?>
initialize() → Future<void>
requestPermission() → Future<void>
setProvider(PushNotificationProvider provider) → void
subscribeToTopic(String topic) → Future<void>
unsubscribeFromTopic(String topic) → Future<void>