ShorebirdUpdater class

Shorebird integration

Constructors

ShorebirdUpdater()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isSupported bool
no setter

Static Methods

checkForUpdate() Future<bool>
downloadUpdate() Future<void>
parseAvailability(String output) bool
Parses the machine-readable availability value when Shorebird emits it, and otherwise conservatively reports no available patch.