dvCurrentSpan top-level property
DVSpan?
get
dvCurrentSpan
The span the current call is inside, if any.
Implementation
DVSpan? get dvCurrentSpan => Zone.current[dvSpanZoneKey] as DVSpan?;
The span the current call is inside, if any.
DVSpan? get dvCurrentSpan => Zone.current[dvSpanZoneKey] as DVSpan?;