dvFlatHeaderLength top-level constant
int
const dvFlatHeaderLength
The magic and version prefix every buffer starts with.
Implementation
const int dvFlatHeaderLength = 8;
The magic and version prefix every buffer starts with.
const int dvFlatHeaderLength = 8;