Auth class
Auth manager
Properties
-
authStateChanges
→ Stream<
AuthUser?> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- provider → AuthProvider
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
currentUser(
) → Future< AuthUser?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signIn(
String email, String password) → Future< AuthUser?> -
signOut(
) → Future< void> -
signUp(
String email, String password, {String? name}) → Future< AuthUser?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
initialize(
AuthProvider provider) → void