DVAIEvalCase class
Constructors
- DVAIEvalCase({required String name, required bool passed, required DVJsonValue expected, DVAIEvalFailure? failure, DVJsonValue? actual, String? model, double? rubricScore})
-
const
Properties
- actual → DVJsonValue?
-
final
- expected → DVJsonValue
-
final
- failure → DVAIEvalFailure?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- model → String?
-
The model that answered.
final
- name → String
-
final
- passed → bool
-
final
- rubricScore → double?
-
Recorded, never deciding.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited