DVAccessibility class
Constructors
- DVAccessibility()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- reducedMotion → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- switchControl → DVSwitchControlState
-
Switch control, on or off, for the whole application. See
DVSwitchControl and DVAccessibilityToggle.
no setter
Methods
-
clearReducedMotion(
) → void - Drops the override and goes back to following the platform.
-
contrast(
{required Color foreground, required Color background, double requiredRatio = 4.5, String name = 'contrast'}) → DVContrastCheck -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
report(
Iterable< DVAccessibilityCheck> checks) → DVAccessibilityReport -
tapTarget(
{required Size size, Size minimumSize = const Size(48, 48), String name = 'tapTarget'}) → DVTappableTargetCheck -
toString(
) → String -
A string representation of this object.
inherited
-
useReducedMotion(
bool value) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited