DVAlertState class
A rule's state, as of the last evaluation.
Constructors
-
DVAlertState({required DVAlertStatus status, DateTime? pendingSince, DateTime? firingSince, bool delivered = false, String? incidentId, String? dedupKey, DateTime? resolvingSince, Set<
String> deliveredTo = const <String>{}, Map<String, String> missed = const <String, String>{}, DateTime? lastNotifiedAt}) -
const
Properties
- dedupKey → String?
-
The key this firing is known by to pagers.
final
- delivered → bool
-
Whether this firing reached at least one target.
final
-
deliveredTo
→ Set<
String> -
The
user:<id>andpager:<name>keys this firing reached.final - firingSince → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- incidentId → String?
-
final
- lastNotifiedAt → DateTime?
-
When this firing last reached somebody, or was first attempted.
final
-
missed
→ Map<
String, String> -
The targets this firing has not reached, keyed
user:<id>,pager:<name>orteam:<name>(a team that could not be resolved to anyone), with the reason from the latest attempt. Each is tried again at the next evaluation while the alert fires.final - pendingSince → DateTime?
-
final
- resolvingSince → DateTime?
-
While firing: since when the condition has been clear. The alert
resolves once that has lasted the rule's resolve delay; null while the
breach holds.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → DVAlertStatus
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited