DVAuthAuthorization class

Constructors

DVAuthAuthorization()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
registeredPolicies Set<String>
Every registered policy, as action:ResourceType.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authorize<TUser, TResource>(TUser user, String action, TResource resource) Future<void>
can<TUser, TResource>(TUser user, String action, TResource resource) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register<TUser, TResource>(String action, DVPolicyCheck<TUser, TResource> check) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited