DVBackfillSettings class final
dartvel.database.tier and dartvel.database.backfill.
Constructors
- DVBackfillSettings({DVDatabaseTier tier = DVDatabaseTier.standard, Duration targetReplicaLag = const Duration(seconds: 5), double maxWriteLatencyIncrease = 0.10, double? floorRate, Duration patience = const Duration(minutes: 15)})
-
const
-
DVBackfillSettings.fromConfig(Map<
Object?, Object?> ? database) -
Reads the
dartvel.databasesection ofpubspec.yaml.factory
Properties
- floor → double
-
no setter
- floorRate → double?
-
Rows per second below which the backfill counts as stuck. Defaults to a
tenth of the tier's starting rate.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxWriteLatencyIncrease → double
-
Write latency increase, as a fraction, above which it halves its rate.
final
- patience → Duration
-
How long it may stay below floor before that is reported
(
DV-SCHEMA-003).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetReplicaLag → Duration
-
Replica lag above which the backfill halves its rate.
final
- tier → DVDatabaseTier
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited