DVBilling class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkout({required BillingPlan plan, required Object customer})
→ Future<DVBillingCheckoutSession>
-
-
grantLocalEntitlement(Object customer, Entitlement entitlement)
→ void
-
-
handleWebhook(String payload, Map<String, String> headers)
→ Future<DVBillingWebhookResult>
-
Verifies a webhook against the configured provider and applies it.
-
hasEntitlement(Object customer, Entitlement entitlement)
→ Future<bool>
-
-
invoices(Object customer, {int limit = 20})
→ Future<List<DVInvoice>>
-
customer's billing history, newest first.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
recordUsage({required Object customer, required DVUsageMeter meter, required int quantity, required String idempotencyKey, DateTime? at})
→ Future<void>
-
Records
quantity against meter for customer.
-
revokeLocalEntitlement(Object customer, Entitlement entitlement)
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
useProvider(DVBillingProvider provider)
→ void
-