DVBilling class

Constructors

DVBilling()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkout({required BillingPlan plan, required Object customer}) Future<DVBillingCheckoutSession>
grantLocalEntitlement(Object customer, Entitlement entitlement) → void
hasEntitlement(Object customer, Entitlement entitlement) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revokeLocalEntitlement(Object customer, Entitlement entitlement) → void
toString() String
A string representation of this object.
inherited
useProvider(DVBillingProvider provider) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited