DVConsentTarget class final
A build target and the ways it has of asking.
Constructors
-
DVConsentTarget(String name, {required Set<
DVConsentPrompt> prompts, bool tracksWithAppTrackingTransparency = false}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
prompts
→ Set<
DVConsentPrompt> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tracksWithAppTrackingTransparency → bool
-
Whether a tracking category needs the App Tracking Transparency prompt
here rather than any prompt at all.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- android → const DVConsentTarget
- ios → const DVConsentTarget
- linux → const DVConsentTarget
- macos → const DVConsentTarget
- tvos → const DVConsentTarget
- web → const DVConsentTarget
- windows → const DVConsentTarget