DVCronSchedule class
One parsed schedule.
Properties
- dayOfMonthRestricted → bool
-
Whether each day field was narrowed from
*.final - dayOfWeekRestricted → bool
-
final
- expression → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
matches(
DateTime time) → bool -
Whether
timeis an occurrence, to the minute. -
nextAfter(
DateTime from) → DateTime? -
The first occurrence strictly after
from, or null if there is none. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String expression) → DVCronSchedule -
Parses
expression, throwing FormatException if it is not a schedule.