DVDeviceProvisioningResult class
Constructors
- DVDeviceProvisioningResult({required String deviceId, required String fleetId, required bool provisioned})
-
const
-
DVDeviceProvisioningResult.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- deviceId → String
-
final
- fleetId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- provisioned → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited