DVDigitalBillable class final
See DVBillable.digital.
- Inheritance
-
- Object
- DVBillable
- DVDigitalBillable
Constructors
- DVDigitalBillable({String? appStore, String? play})
-
const
Properties
Methods
-
identifierOn(
DVStore store) → String? -
The identifier
storeknows this product by, or null when none was declared. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited