DVDisplayHint class final
Which display a window is asking for.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
byId(
String id) → DVDisplayHint -
The display with
id. -
byIndex(
int index) → DVDisplayHint -
The display at
indexin OS order. -
byName(
String name) → DVDisplayHint -
The display named
name, usually from a device profile.
Constants
- primary → const DVDisplayHint
- The primary display.
- secondary → const DVDisplayHint
- The first non-primary display, in the order the OS reports them.