DVFakeAudioFocusBackend class final
Audio focus the test grants, refuses and takes away.
- Implemented types
Constructors
- DVFakeAudioFocusBackend({bool grant = true})
Properties
- abandons ↔ int
-
getter/setter pair
- grant ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- held ↔ bool
-
getter/setter pair
-
losses
→ Stream<
void> -
Fires when the platform takes focus away: an incoming call, another
application starting playback.
no setteroverride
- requests ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
abandon(
) → Future< void> -
Gives focus back.
override
-
loseFocus(
) → void - The platform takes focus away.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request(
) → Future< bool> -
Asks the platform for focus. False when it refused -- a call in
progress, another application holding exclusive focus.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited