DVFakeMediaTimers class final
Timers that fire when the test says time has passed.
- Implemented types
Constructors
Properties
Methods
-
elapse(
Duration by) → void -
Advances time by
by, firing every timer that falls due, in order. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
Duration after, void onFire()) → DVMediaTimer -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited