DVFlagRollout class
A percentage of a population, chosen by hashing rather than by chance.
Constructors
- DVFlagRollout.percentage(num percent, {required DVFlagSubject by})
-
percentof subjects identified byby, from 0 to 100.factory
Properties
- basisPoints → int
-
The threshold, out of 10,000.
final
- by → DVFlagSubject
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited