DVGateOverrideRecord class final
An override that let a hold through: what to write where overrides are kept.
Constructors
Properties
- at → DateTime
-
final
- by → String
-
final
- code → String?
-
final
-
evidence
→ Map<
String, Object?> -
final
- gate → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- overrode → String
-
The hold's own reason.
final
- reason → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited