triangles property
Triangles the default scene draws: each mesh counted once per node that uses it, strips and fans as the triangles they make, points and lines as none.
Implementation
final int triangles;
Triangles the default scene draws: each mesh counted once per node that uses it, strips and fans as the triangles they make, points and lines as none.
final int triangles;