DVHttpStreamSend typedef
DVHttpStreamSend =
Future<DVHttpStreamedResponse> Function(DVHttpRequest request)
Puts one outbound request on the wire and yields its response as it arrives. dvStreamHttpRequest by default; replaceable for a test that wants to be the wire itself.
Implementation
typedef DVHttpStreamSend = Future<DVHttpStreamedResponse> Function(
DVHttpRequest request);