titleSource property
Who wrote title: alert, crash or human, as for an entry.
When not given it is the source of the entry that opened the incident, which is who DVIncidents.openIncident titled it for -- and what an incident stored before titles were attributed is read as.
Implementation
String titleSource;