DVIncidents class
Opens, updates and resolves incidents.
Constructors
- DVIncidents({required DVIncidentStore store, DateTime clock()?, String newId()?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- store → DVIncidentStore
-
final
Methods
-
find(
String id) → Future< DVIncident?> -
linkCrashSpike(
{required String fingerprint, required String release, required String message, DateTime? now}) → Future< DVIncident> - Links a crash spike into the newest open incident, or opens one.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
open(
) → Future< List< DVIncident> > - Open incidents, newest first.
-
openIncident(
{required String title, required String message, List< String> components = const <String>[], String? rule, String source = 'human', bool public = false, DateTime? now}) → Future<DVIncident> -
resolve(
String id, {required String message, String? actor, DateTime? now}) → Future< DVIncident> - Declares the incident over, in public.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String id, {required String message, DVIncidentStatus? status, bool public = false, String source = 'human', String? rule, String? title, String? actor, DateTime? now}) → Future< DVIncident> -
Appends
messageto the timeline, moving the incident tostatuswhen given.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited