DVInfraManifest class final
One environment under dartvel.infra.
Constructors
-
DVInfraManifest({required String environment, required DVInfraAdapterKind adapter, required List<
String> hosts, DVInfraSsh ssh = const DVInfraSsh(), DVInfraTls? tls, String? proxy, DVInfraServices services = const DVInfraServices(), DVInfraDatabase? database, String? logsShip}) -
const
Properties
- adapter → DVInfraAdapterKind
-
final
- database → DVInfraDatabase?
-
final
- environment → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hosts
→ List<
String> -
final
- logsShip → String?
-
final
- proxy → String?
-
The reverse proxy adapter; only
caddyis read.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- services → DVInfraServices
-
final
- ssh → DVInfraSsh
-
final
- tls → DVInfraTls?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromConfig(
Object? infra) → Map< String, DVInfraManifest> -
Reads the
dartvel.inframap, keyed by environment.