DVInstall class
DV.Platform.install.
Constructors
- DVInstall()
-
const
Properties
- canPrompt → bool
-
Whether an install can be offered right now.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInstalled → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAvailabilityChanged(
void onChanged(bool available)) → void Function() - Called when the app becomes installable, or stops being.
-
prompt(
) → Future< DVInstallOutcome> - Shows the browser's install prompt.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited