DVJobEnvelope<TPayload> class
Constructors
- DVJobEnvelope({required String id, required String queue, required Type payloadType, required TPayload payload, required int priority, required int maxAttempts, required Duration backoff, required DateTime createdAt, required int attempts, required DVJobState state, String? lastError, String? tenant})
-
const
Properties
- attempts → int
-
final
- backoff → Duration
-
final
- createdAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- lastError → String?
-
final
- maxAttempts → int
-
final
- payload → TPayload
-
final
- payloadType → Type
-
final
- priority → int
-
final
- queue → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → DVJobState
-
final
- tenant → String?
-
The tenant the job was dispatched under, or null for none.
final
Methods
-
copyWith(
{int? attempts, DVJobState? state, String? lastError}) → DVJobEnvelope< TPayload> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited