DVKioskTarget enum
The targets the specification gives a kiosk row.
Values
- sonyELinux → const DVKioskTarget
- androidDeviceOwner → const DVKioskTarget
- androidScreenPinning → const DVKioskTarget
- iPadOS → const DVKioskTarget
- windows → const DVKioskTarget
- macos → const DVKioskTarget
- linuxDesktop → const DVKioskTarget
- tizen → const DVKioskTarget
- webos → const DVKioskTarget
- web → const DVKioskTarget
- browserExtension → const DVKioskTarget
- watch → const DVKioskTarget
- terminal → const DVKioskTarget
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DVKioskTarget> - A constant List of the values in this enum, in order of their declaration.