DVLocalBillingProvider class

Implemented types

Constructors

DVLocalBillingProvider()

Properties

grants Map<String, Set<String>>
Who holds what, for an entitlements view.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkout({required BillingPlan plan, required Object customer}) Future<DVBillingCheckoutSession>
override
grant(Object customer, Entitlement entitlement) → void
hasEntitlement(Object customer, Entitlement entitlement) Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revoke(Object customer, Entitlement entitlement) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited