DVMagicLink class

An issued magic link.

Constructors

DVMagicLink({required Uri url, required String token, required DateTime expiresAt})
const

Properties

expiresAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
The raw token, if the caller wants to compose its own message.
final
url Uri
The URL to send. It carries the only copy of the secret.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited