DVMemoryAuthTokenStore class
In-memory store. Fine for one process; use a database- or cache-backed store when more than one serves the same users.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String lookup) → Future< void> -
override
-
get(
String lookup) → Future< DVAuthTokenRecord?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put(
String lookup, DVAuthTokenRecord record) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String lookup, DVAuthTokenRecord record) → Future< void> -
Replaces a record, for attempt counting.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited