address property
The native address of the first byte, or 0 when the segment lives on the Dart heap (web, or DVMemoryHeapBacking) and has none.
Implementation
@override
int get address => 0;
The native address of the first byte, or 0 when the segment lives on the Dart heap (web, or DVMemoryHeapBacking) and has none.
@override
int get address => 0;