DVMeterOutcome class
What happened to one recording, or one level check.
Constructors
Properties
- admitted → bool
-
Whether the call the recording was for may proceed.
final
- applied → DVQuota?
-
The behaviour applied at the limit, or null when under it.
final
-
codes
→ List<
String> -
The diagnostic codes this recording raised, in the order raised.
final
-
crossed
→ List<
double> -
The notification thresholds this recording crossed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → num?
-
final
- overage → num
-
The amount past the limit that will be billed, under
DVQuota.allowAndBill.
final
- period → DVMeterPeriod
-
final
- recorded → bool
-
Whether a record was stored. False for a duplicate and for a block.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → num
-
Usage in period after this recording.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited