DVModelDataApi class
Answers dvModelDataPath for the models designed in Studio.
Constructors
-
DVModelDataApi({required DVDatabaseAdapter? database(), Future<
bool> team(Request request)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
respond(
Request request) → Future< Response?> -
The answer to
request, or null for a request that is not the data API's -- including one for a model that is not designed in Studio, which the application answers as any path it does not serve. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited