DVMySqlException class
Thrown when MySQL reports an error.
- Implemented types
Constructors
- DVMySqlException(int code, String message, {String? sqlState})
-
const
Properties
- code → int
-
The server error code, e.g. 1146 for an unknown table.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sqlState → String?
-
The SQLSTATE, when the server sent one.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited