DVNativeBridge class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Properties
-
registered
→ List<String>
-
Every binding a handler is registered for, sorted: what this build on
this platform can actually do, as opposed to the names declared.
no setter