push<T extends Object?> method
Pushes target onto the navigation stack, keeping the current page.
Implementation
Future<T?> push<T extends Object?>(DVRouteTarget target) =>
_active.push<T>(target.path);
Pushes target onto the navigation stack, keeping the current page.
Future<T?> push<T extends Object?>(DVRouteTarget target) =>
_active.push<T>(target.path);