DVOAuth2Config class
Endpoints and client identity for one identity provider.
Constructors
Properties
-
final
- clientId → String
-
final
- clientSecret → String?
-
Omitted for public clients, where PKCE alone protects the exchange.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- redirectUri → Uri
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> -
final
- tokenEndpoint → Uri
-
final
- userInfoEndpoint → Uri?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
bitbucket(
{required String clientId, required Uri redirectUri, String? clientSecret, List< String> scopes = const <String>['account']}) → DVOAuth2Config -
github(
{required String clientId, required Uri redirectUri, String? clientSecret, List< String> scopes = const <String>['read:user', 'user:email']}) → DVOAuth2Config -
gitlab(
{required String clientId, required Uri redirectUri, String? clientSecret, Uri? host, List< String> scopes = const <String>['read_user']}) → DVOAuth2Config -
google(
{required String clientId, required Uri redirectUri, String? clientSecret, List< String> scopes = const <String>['openid', 'email', 'profile']}) → DVOAuth2Config -
Endpoints for the identity providers the spec names. Each still needs a
clientIdandredirectUri. -
microsoft(
{required String clientId, required Uri redirectUri, String tenant = 'common', String? clientSecret, List< String> scopes = const <String>['openid', 'email', 'profile']}) → DVOAuth2Config