DVOAuthSettings class
How long the OAuth provider's codes and tokens live.
Constructors
- DVOAuthSettings({Duration codeLifetime = const Duration(minutes: 1), Duration accessTokenLifetime = const Duration(hours: 1), Duration refreshTokenLifetime = const Duration(days: 30), String? issuer})
-
const
Properties
- accessTokenLifetime → Duration
-
final
- codeLifetime → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuer → String?
-
The issuer the RFC 8414 metadata names, as an origin such as
https://api.example.com. Null means the origin each request named, which is right behind no proxy and wrong behind one.final - refreshTokenLifetime → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited