DVOfflineTaxTable class
The kiosk that cannot ask: a declared table with an expiry.
dartvel:
tax:
offline:
table: assets/tax/gb-2026.json
staleAfter: 14d
Constructors
- DVOfflineTaxTable({required DVTaxTable table, required Duration staleAfter})
-
DVOfflineTaxTable.fromConfig(Map<
String, Object?> config, {required String read(String path)}) -
Reads the
dartvel.tax.offlineblock, loading the table throughread.factory
Properties
- expiresAt → DateTime
-
The moment sales stop being priced from this table.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- staleAfter → Duration
-
final
- table → DVTaxTable
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parseStaleAfter(
String value) → Duration -
14dor36h.