DVPayoutReservation class
What reserving a payout did.
Constructors
- DVPayoutReservation({DVPayoutRecord? record, bool existed = false})
-
const
Properties
- existed → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- record → DVPayoutRecord?
-
Null when nothing was available.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited