DVPreviewFinding class final
One diagnostic raised while planning, creating or tearing down a preview.
Constructors
- DVPreviewFinding(String code, String message)
Properties
- code → String
-
A
DV-PREVIEW-*code from the diagnostic registry.final - hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool
-
no setter
- level → String
-
The registry's level for code, so a finding cannot disagree with it.
final
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited