DVPrintResult class
Constructors
- DVPrintResult({required int pages, String? path})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pages → int
-
final
- path → String?
-
Where the PDF was written, for DVPrinting.toFile; null for a dialog.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited