DVPromotionRefusal enum
Why a promotion did not apply.
Values
- unknown → const DVPromotionRefusal
-
No promotion has the code.
- duplicate → const DVPromotionRefusal
-
The code was given twice.
- notLive → const DVPromotionRefusal
-
Before its start or at or after its end.
- notApplicable → const DVPromotionRefusal
-
Nothing in the order is discounted by it, including a fixed amount in another currency.
- belowMinimum → const DVPromotionRefusal
-
The order is below its minimum.
- limitReached → const DVPromotionRefusal
-
Redeemed as many times as it may be.
- customerLimitReached → const DVPromotionRefusal
-
Redeemed by this customer as many times as they may.
- ineligible → const DVPromotionRefusal
-
Its policy refused this customer:
DV-COMMERCE-003. - notStacked → const DVPromotionRefusal
-
Another promotion in its group, or an exclusive one, gave more.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DVPromotionRefusal> - A constant List of the values in this enum, in order of their declaration.