DVPromptTemplate class
A prompt as it is written in source.
Constructors
-
DVPromptTemplate({required String system, Map<
String, Type> input = const <String, Type>{}, Type? output, DVJsonObject schema = const <String, DVJsonValue>{}}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
input
→ Map<
String, Type> -
The inputs the call site passes, by name and type.
final
- output → Type?
-
The type the output is read into. Recorded by name in the fingerprint.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → DVJsonObject
-
The JSON Schema a structured answer is requested with. Empty means the
prompt is answered as plain text.
final
- system → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited