DVProtocolAdapterSet class
Serves one degraded protocol version.
Properties
Methods
-
arguments(
String function, Map< String, Object?> args) → Map<String, Object?> - The arguments an old client sent, as the current function reads them.
-
model(
String model, Object? value) → Object? -
A current record of
model, in the old client's vocabulary. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
result(
String function, Object? value) → Object? - A backend function's current result, in the old client's vocabulary.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited