DVProtocolChangeKind enum
Values
- modelAdded → const DVProtocolChangeKind
- modelRemoved → const DVProtocolChangeKind
- syncChanged → const DVProtocolChangeKind
- fieldAdded → const DVProtocolChangeKind
- fieldRemoved → const DVProtocolChangeKind
- fieldRenamed → const DVProtocolChangeKind
- fieldTypeChanged → const DVProtocolChangeKind
- enumAdded → const DVProtocolChangeKind
- enumRemoved → const DVProtocolChangeKind
- enumMemberAdded → const DVProtocolChangeKind
- enumMemberRemoved → const DVProtocolChangeKind
- functionAdded → const DVProtocolChangeKind
- functionRemoved → const DVProtocolChangeKind
- parameterAdded → const DVProtocolChangeKind
- parameterRemoved → const DVProtocolChangeKind
- parameterRenamed → const DVProtocolChangeKind
- parameterTypeChanged → const DVProtocolChangeKind
- returnTypeChanged → const DVProtocolChangeKind
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DVProtocolChangeKind> - A constant List of the values in this enum, in order of their declaration.