DVQueueAdapter class abstract

Constructors

DVQueueAdapter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

complete(String id) → Future<void>
deadLetters(String queue) → Future<List<DVJobEnvelope<DVJobPayload>>>
discard(String id) → Future<bool>
Drops one dead-lettered job. Flushing a queue to be rid of a single poison message would take every other job with it.
enqueue<TPayload>(String queue, TPayload payload, {int priority, int maxAttempts, Duration backoff, String? tenant}) → Future<DVJobEnvelope<TPayload>>
Stores payload on queue.
fail(String id, String error, StackTrace stackTrace) → Future<void>
flush(String queue) → Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pending(String queue) → Future<List<DVJobEnvelope<DVJobPayload>>>
reserve(String queue) → Future<DVJobEnvelope<DVJobPayload>?>
retry(String id) → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited