DVQueues class
Constructors
- DVQueues()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deadLetters(
[String queue = 'default']) → Future< List< DVJobEnvelope< >DVJobPayload> > -
discard(
String id) → Future< bool> - Drops one dead-lettered job, for a message that will never succeed.
-
dispatch<
TPayload> (TPayload payload, {String queue = 'default', int priority = 0, int maxAttempts = 3, Duration backoff = const Duration(seconds: 30)}) → Future< DVJobEnvelope< TPayload> > -
flush(
{String queue = 'default'}) → Future< int> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pending(
[String queue = 'default']) → Future< List< DVJobEnvelope< >DVJobPayload> > -
register<
TPayload> (DVJobHandler< TPayload> handler) → void -
retry(
String id) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
-
useAdapter(
DVQueueAdapter adapter) → void -
work(
{String queue = 'default', int maxJobs = 1}) → Future< int>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited