DVReleaseHealthDecision class
What the gate decided.
Constructors
-
DVReleaseHealthDecision({required bool hold, required List<
String> heldCohorts, required List<String> flagsToTurnOff, required DVReleaseHealthNumbers overall}) -
const
Properties
-
flagsToTurnOff
→ List<
String> -
Flags the release staged behind, to turn off when it is held.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
heldCohorts
→ List<
String> -
The cohorts below threshold. Empty with hold true when it is the
release as a whole.
final
- hold → bool
-
final
- overall → DVReleaseHealthNumbers
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited