DVRouteOrderException class
Routes that cannot be put in any order where each is reachable.
- Implemented types
Constructors
- DVRouteOrderException({required (String, String) first, required (String, String) second})
-
const
Properties
- first → (String, String)
-
A path that has to be matched before another, as
(specific, general).final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- second → (String, String)
-
The opposite requirement, from the same two groups.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited