DVSceneBoxFactory class
DVBox.scene(...).
A callable rather than a constructor so the box keeps its one layout
vocabulary and DVBox.scene can grow siblings, such as the specification's
DVBox.scene.game(...), without a second widget type.
Constructors
- DVSceneBoxFactory()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
DVScene scene, {DVSceneController? controller, DVModifier? modifier}) → DVBox< Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited