DVSceneDraw class final
One thing to draw.
Constructors
- DVSceneDraw({required String nodeId, required DVMat4 world, DVSceneResource? resource, DVScenePrimitive? primitive, DVSceneResource? material})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- material → DVSceneResource?
-
final
- nodeId → String
-
final
- primitive → DVScenePrimitive?
-
The shape, for a mesh node.
final
- resource → DVSceneResource?
-
The model's resource, for a model node.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- world → DVMat4
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited