DVSceneLight class final
A light's parameters.
Constructors
- DVSceneLight.directional({required DVVec3 direction, int color = 0xFFFFFF, double intensity = 1, bool castShadows = false})
-
const
- DVSceneLight.point({int color = 0xFFFFFF, double intensity = 1, double? range, bool castShadows = false})
-
const
- DVSceneLight.spot({required DVVec3 direction, int color = 0xFFFFFF, double intensity = 1, double? range, double? innerConeDegrees = 0, double? outerConeDegrees = 45, bool castShadows = false})
-
const
Properties
- castShadows → bool
-
final
- color → int
-
0xRRGGBB.
final
- direction → DVVec3?
-
The direction light travels, for directional and spot lights.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- innerConeDegrees → double?
-
final
- intensity → double
-
final
- outerConeDegrees → double?
-
final
- range → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → DVSceneLightType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
-
withShadows(
[bool cast = true]) → DVSceneLight
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Object? json, String path) → DVSceneLight