Answers what a change costs on one server.
Implemented by a database adapter, which is the thing that knows the server
and its version. null means the adapter cannot classify the change.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
classify(
DVSchemaChange change) → FutureOr< DVSchemaChangeClass?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited