DVSemanticHit<T> class
Constructors
-
DVSemanticHit({required T record, required double score, DVTextChunk? chunk, String? field, Set<
DVSearchMode> matchedBy = const <DVSearchMode>{}}) -
const
Properties
- chunk → DVTextChunk?
-
The chunk that matched, for a semantic match.
final
- field → String?
-
The field chunk is from.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
matchedBy
→ Set<
DVSearchMode> -
Which rankings found it: keyword, semantic, or both in hybrid mode.
final
- record → T
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited