DVSessionCheck class
The outcome of checking a token.
Constructors
- DVSessionCheck.failed(DVSessionFailure failure)
-
const
- DVSessionCheck.valid(DVSession session)
-
const
Properties
- code → String?
-
The diagnostic a revoked session reports (
DV-SESSION-002), or null.no setter - failure → DVSessionFailure?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session → DVSession?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited