DVShellCommand class

Constructors

DVShellCommand(String executable, {List<String> arguments = const <String>[], Map<String, String> environment = const <String, String>{}, String? workingDirectory})
const

Properties

arguments List<String>
final
environment Map<String, String>
final
executable String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workingDirectory String?
final

Methods

arg(String value) DVShellCommand
args(Iterable<String> values) DVShellCommand
cwd(String path) DVShellCommand
env(String key, String value) DVShellCommand
envAll(Map<String, String> values) DVShellCommand
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited