DVSignalReaders class
Resolves a DVSignalRef to a reading.
Constructors
-
DVSignalReaders({DVMetrics? metrics, Iterable<
DVSpanSample> spans()?, DVReleaseHealth? releaseHealth, DVServiceLevels? serviceLevels})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- metrics → DVMetrics
-
final
- releaseHealth → DVReleaseHealth?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceLevels → DVServiceLevels?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
DVSignalRef ref, {required DateTime now}) → DVSignalReading -
register(
DVSignalRef ref, DVSignalReader reader) → void -
Reads
refthroughreader, ahead of any built-in source. -
toString(
) → String -
A string representation of this object.
inherited
-
unregister(
DVSignalRef ref) → void -
After this, a rule naming
refreads it as missing.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited