DVSmtpException class
Thrown when the server answers with an unexpected status.
- Implemented types
Constructors
- DVSmtpException(String command, String response, {int? code})
-
const
Properties
- code → int?
-
final
- command → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTransient → bool
-
4xx is transient and worth retrying; 5xx is permanent.
no setter
- response → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited