DVSpatialRefusal enum
Why a request was not presented in space.
Values
- noCapability → const DVSpatialRefusal
-
The target has no spatial capability for this kind (
DV-WINDOW-014,DV-WINDOW-015). - exclusive → const DVSpatialRefusal
-
An immersive space is already open in this application.
- backgrounded → const DVSpatialRefusal
-
The application was not on screen.
- bindingMissing → const DVSpatialRefusal
-
The capability was reported and no device binding is there (
DV-XR-006). - bindingFailed → const DVSpatialRefusal
-
A binding threw (
DV-XR-006). - platformRefused → const DVSpatialRefusal
-
The platform declined (
DV-WINDOW-004).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DVSpatialRefusal> - A constant List of the values in this enum, in order of their declaration.