DVStudioIconButton class
A square icon control with a hover state: toolbar actions, rail items, panel header actions.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DVStudioIconButton
Constructors
- DVStudioIconButton({Key? key, required IconData icon, required String tooltip, VoidCallback? onTap, bool selected = false, bool onRail = false, double size = 32, Color? ink})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
final
- ink → Color?
-
The glyph's colour when the button is neither selected nor off, for the
toolbar, where the icons are the words of the button and are drawn in the
body ink rather than the muted one panel headers use.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onRail → bool
-
For the dark navigation rail.
final
- onTap → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
final
- size → double
-
final
- tooltip → String
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DVStudioIconButton> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited