DVTaxAddress class
Where a sale is taxed: normally the customer's billing address.
Constructors
Properties
- city → String?
-
final
- country → String
-
ISO 3166-1 alpha-2, in either case.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
jurisdictionKeys
→ List<
String> -
Jurisdiction keys from most to least specific.
no setter
- line1 → String?
-
final
- postalCode → String?
-
final
- region → String?
-
The ISO 3166-2 subdivision, with or without its country prefix:
NYorUS-NY.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited