DVTrackResult class final
What DVAnalytics.track did with an event.
Constructors
- DVTrackResult.refused({String? code, required String reason})
-
An event that was not recorded for a reason outside the pipeline, such
as a pipeline that could not start.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited