DVTranslationCatalog class
Constructors
-
DVTranslationCatalog({required LocaleTag locale, Map<
DVTranslationKey, String> messages = const <DVTranslationKey, String>{}, Map<DVTranslationKey, DVPluralForms> plurals = const <DVTranslationKey, DVPluralForms>{}}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- locale → LocaleTag
-
final
-
messages
→ Map<
DVTranslationKey, String> -
final
-
plurals
→ Map<
DVTranslationKey, DVPluralForms> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited