DVWebhookSubscription class
Where a customer asked for events to be sent.
Constructors
Properties
- consecutiveFailures → int
-
final
- createdAt → DateTime
-
final
- disabled → bool
-
final
-
events
→ Set<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- overlapUntil → DateTime?
-
final
- previousSigningSecret → String?
-
The key being rotated out, signed with alongside signingSecret until
overlapUntil.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signingSecret → String
-
The name of the secret holding the signing key — a name, resolved
through
DVSecretsat signing time, never the key itself.final - tenant → String?
-
final
- url → Uri
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited