DVWorkerResponse class final
A message from the worker.
Constructors
- DVWorkerResponse({required int id, required DVWorkerResponseKind kind, double? fraction, String? message, Object? value, DVWorkerFailureKind? failureKind, String? error, String? stack})
-
const
-
DVWorkerResponse.fromMessage(Map<
Object?, Object?> message) -
factory
Properties
- error → String?
-
final
- failure → DVWorkerFailure
-
What the page's pool is told.
no setter
- failureKind → DVWorkerFailureKind?
-
final
- fraction → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- kind → DVWorkerResponseKind
-
final
- message → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stack → String?
-
final
- value → Object?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited