FirebasePushProvider class
Firebase Cloud Messaging, HTTP v1.
The recipient is an FCM registration token. A stale token surfaces as a DVPushProviderException whose DVPushProviderException.isUnregisteredToken is true, which is the signal to drop it rather than retry.
- Implemented types
Constructors
- FirebasePushProvider({required String projectId, required DVAccessTokenSupplier accessToken, Uri? baseUrl, DVHttpSend transport = dvSendHttpRequest})
Properties
- accessToken → DVAccessTokenSupplier
-
final
- baseUrl → Uri
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → DVNotificationProviderKind
-
no setteroverride
- projectId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transport → DVHttpSend
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
String recipient, DVNotificationMessage message) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited