ResendMailProvider class
Resend (https://resend.com) transactional mail.
- Inheritance
-
- Object
- DVHttpMailProvider
- ResendMailProvider
Constructors
- ResendMailProvider({required String apiKey, Uri? baseUrl, DVHttpSend transport = dvSendHttpRequest})
Properties
- apiKey → String
-
finalinherited
- baseUrl → Uri
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- providerName → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transport → DVHttpSend
-
finalinherited
Methods
-
buildRequest(
DVMailMessage message) → DVHttpRequest -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
DVMailMessage message) → Future< void> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited