TlsConfig class

TLS configuration.

Constructors

TlsConfig({required String certPem, required String keyPem})
Default constructor.
const

Properties

certPem String
Certificate PEM string.
final
hashCode int
The hash code for this object.
no setterinherited
keyPem String
Key PEM string.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited