dvRenderPage function
The shell as the page for path from data: the head, the text, the
structured data and the favicon, all from the data.
Implementation
String dvRenderPage({
required String shell,
required String path,
required DVPageData data,
String? siteUrl,
String? siteName,
String? description,
String? image,
}) =>
dvApplyPageExtras(
dvRenderRoute(
shell: shell,
path: path,
title: data.title,
text: data.text,
siteUrl: siteUrl,
description: data.description ?? description,
image: data.image ?? image,
siteName: siteName,
),
data,
);